# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic
Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

### Added

### Changed

### Deprecated

### Fixed

## [0.0.1] - 2024-06-24

Initial release of the optimizer that is close to the version we used in the paper.

[unreleased]: https://github.com/f-dangel/sirfshampoo/compare/v0.0.1...HEAD
[0.0.1]: https://github.com/f-dangel/sirfshampoo/compare/c97d2915d7cbed98ab9e24bee30cf1f1274fa29d...v0.0.1
